@@ -3,7 +3,7 @@
 """
 MIT License
 
-Copyright (c) 2020 Michael Alonge <malonge11@gmail.com>
+Copyright (c) 2021 Michael Alonge <malonge11@gmail.com>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -50,11 +50,11 @@ def main():
     agp_file_list = [os.path.abspath(i) for i in args.agp]
     for agp_file in agp_file_list:
         print()
-        log("Checking {} ...".format(agp_file))
+        log("INFO", "Checking {} ...".format(agp_file))
         agp = AGPFile(agp_file, mode="r")
         for _ in agp.iterate_lines():
             pass
-        log("Check for {} is complete with no errors.".format(agp_file))
+        log("INFO", "Check for {} is complete with no errors.".format(agp_file))
 
 
 if __name__ == "__main__":
