@@ -326,7 +326,7 @@ def write_breaks(out_file, query_file, ctg_breaks, overwrite, remove_suffix):
 
 
 def main():
-    description = "Homology-based assembly correction: Correct sequences in 'query.fa' by comparing them to " \
+    description = "Homology-based misassembly correction: Correct sequences in 'query.fa' by comparing them to " \
                   "sequences in 'reference.fa'>"
     parser = argparse.ArgumentParser(description=description, usage="ragtag.py correct <reference.fa> <query.fa>")
 
@@ -355,8 +355,8 @@ def main():
     mm2_default = "-x asm5"
     aln_options.add_argument("-t", metavar="INT", type=int, default=1, help="number of minimap2/unimap threads [1]")
     aln_options.add_argument("--aligner", metavar="PATH", type=str, default="minimap2", help="whole genome aligner executable ('nucmer', 'unimap' or 'minimap2') [minimap2]")
-    aln_options.add_argument("--mm2-params", metavar="STR", type=str, default=mm2_default, help="space delimited minimap2 whole genome alignment parameters ['%s']" % mm2_default)
-    aln_options.add_argument("--unimap-params", metavar="STR", type=str, default=mm2_default, help="space delimited unimap parameters ['%s']" % mm2_default)
+    aln_options.add_argument("--mm2-params", metavar="STR", type=str, default=mm2_default, help="space delimited minimap2 whole genome alignment parameters (overrides '-t') ['%s']" % mm2_default)
+    aln_options.add_argument("--unimap-params", metavar="STR", type=str, default=mm2_default, help="space delimited unimap parameters (overrides '-t') ['%s']" % mm2_default)
     aln_options.add_argument("--nucmer-params", metavar="STR", type=str, default="--maxmatch -l 100 -c 500", help="space delimted nucmer whole genome alignment parameters ['--maxmatch -l 100 -c 500']")
 
     val_options = parser.add_argument_group("validation options")
