@@ -173,7 +173,7 @@ def build_aln_scaffold_graph(ctg_alns, components_fn, max_term_dist):
 
 
 def main():
-    description = "Homology-based continuous assembly scaffolding and gap-filling: Make continuous joins and fill gaps " \
+    description = "Homology-based assembly patching: Make continuous joins and fill gaps " \
                   "in 'target.fa' using sequences from 'query.fa'"
 
     parser = argparse.ArgumentParser(description=description, usage="ragtag.py patch <target.fa> <query.fa>")
@@ -203,8 +203,8 @@ def main():
     aln_options.add_argument("-t", metavar="INT", type=int, default=1, help="number of minimap2/unimap threads [1]")
     aln_options.add_argument("--aligner", metavar="PATH", type=str, default="nucmer", help="aligner executable ('nucmer' (recommended), 'unimap' or 'minimap2') [nucmer]")
     mm2_default = "-x asm5"
-    aln_options.add_argument("--mm2-params", metavar="STR", type=str, default=mm2_default, help="space delimited minimap2 parameters ['%s']" % mm2_default)
-    aln_options.add_argument("--unimap-params", metavar="STR", type=str, default=mm2_default, help="space delimited unimap parameters ['%s']" % mm2_default)
+    aln_options.add_argument("--mm2-params", metavar="STR", type=str, default=mm2_default, help="space delimited minimap2 parameters (overrides '-t') ['%s']" % mm2_default)
+    aln_options.add_argument("--unimap-params", metavar="STR", type=str, default=mm2_default, help="space delimited unimap parameters (overrides '-t') ['%s']" % mm2_default)
     aln_options.add_argument("--nucmer-params", metavar="STR", type=str, default="--maxmatch -l 100 -c 500", help="space delimted nucmer parameters ['--maxmatch -l 100 -c 500']")
 
     args = parser.parse_args()
@@ -466,12 +466,12 @@ def main():
 
     # Remove known false edges
     for u, v in agp_psg.edges:
-        for neighbor in aln_psg.neighbors(u):
+        for neighbor in list(aln_psg.neighbors(u)):
             if neighbor != v:
                 aln_psg.remove_edge(u, neighbor)
                 aln_psg.remove_edge(neighbor, u)
 
-        for neighbor in aln_psg.neighbors(v):
+        for neighbor in list(aln_psg.neighbors(v)):
             if neighbor != u:
                 aln_psg.remove_edge(neighbor, v)
                 aln_psg.remove_edge(v, neighbor)
